@@ -2,7 +2,7 @@ pub mod api;
 pub mod error;
 pub mod response;
 mod client;
-use api::{account::AccountApi, message::MessageApi};
+use api::{account::*, message::*};
 use client::Client as Clientx;
 
 #[derive(Clone)]
