@@ -32,7 +32,7 @@ pub struct RespHolder<T> {
     #[serde(flatten)]
     error: BaseResponse,
     #[serde(flatten)]
-    data: T
+    data: Option<T>
 }
 
 impl<T> Response<T> for RespHolder<T> {
@@ -43,7 +43,7 @@ impl<T> Response<T> for RespHolder<T> {
                 msg: self.error.error_info
             })
         } else {
-            Ok(self.data)
+            Ok(self.data.expect("tcloud return ok with empty body"))
         }
     }
 }
\ No newline at end of file
